<H1 CLASS="western" style="text-align:center;">ZebraZoom</H1>

<p align="center">
<img src="https://zebrazoom.org/videos/gif/output1.gif" height="250">
<img src="https://zebrazoom.org/videos/gif/output2.gif" height="250">
<img src="https://zebrazoom.org/videos/gif/output3.gif" height="250">
<img src="https://zebrazoom.org/videos/gif/output4.gif" height="250">
<img src="https://zebrazoom.org/videos/gif/ER.gif" height="250">
<img src="https://zebrazoom.org/videos/gif/mouse.gif" height="250">
</p>

<p>
ZebraZoom can be used to track the heads and tails of freely swimming and of head-embedded larval and adult zebrafish. It can also be used to track the center of mass of other animal species, such as mice or drosophila. The graphical user interface of ZebraZoom offers options to compare populations based on kinematic parameters and/or on based on unsupervised clustering of bouts of movements. The software operates through an intuitive graphical user interface, making it very simple to use for people with no programming background.

For more information view the <a href="https://zebrazoom.org/documentation/docs/intro/" target="_blank">online documentation</a>, visit <a href="https://zebrazoom.org/" target="_blank">zebrazoom.org</a> or email us info@zebrazoom.org<br/>

</p>
